==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleFromFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RuleFromFluent<A extends RuleFromFluent<A>> extends BaseFluent<A>{
  public RuleFromFluent() {
  }
  public RuleFromFluent(RuleFrom instance) {
    instance = (instance != null ? instance : new RuleFrom());

    if (instance != null) {
      this.withSource(instance.getSource());
      this.withSource(instance.getSource());
    }
  }
  private SourceBuilder source;
  public Source buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  public A withSource(Source source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  public boolean hasSource() {
    return this.source != null;
  }
  public SourceNested<A> withNewSource() {
    return new SourceNested(null);
  }
  public SourceNested<A> withNewSourceLike(Source item) {
    return new SourceNested(item);
  }
  public SourceNested<A> editSource() {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(null));
  }
  public SourceNested<A> editOrNewSource() {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(new SourceBuilder().build()));
  }
  public SourceNested<A> editOrNewSourceLike(Source item) {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuleFromFluent that = (RuleFromFluent) o;
    if (!java.util.Objects.equals(source, that.source)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(source,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  public class SourceNested<N> extends SourceFluent<SourceNested<N>> implements Nested<N>{
    SourceNested(Source item) {
      this.builder = new SourceBuilder(this, item);
    }
    SourceBuilder builder;
    public N and() {
      return (N) RuleFromFluent.this.withSource(builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleFromFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RuleFromFluent<A extends RuleFromFluent<A>> extends BaseFluent<A>{
  public RuleFromFluent() {
  }
  
  public RuleFromFluent(RuleFrom instance) {
    this.copyInstance(instance);
  }
  private SourceBuilder source;
  
  protected void copyInstance(RuleFrom instance) {
    instance = (instance != null ? instance : new RuleFrom());
  
    if (instance != null) {
        this.withSource(instance.getSource());
        this.withSource(instance.getSource());
      }
  }
  
  public Source buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  
  public A withSource(Source source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  
  public boolean hasSource() {
    return this.source != null;
  }
  
  public SourceNested<A> withNewSource() {
    return new SourceNested(null);
  }
  
  public SourceNested<A> withNewSourceLike(Source item) {
    return new SourceNested(item);
  }
  
  public SourceNested<A> editSource() {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(null));
  }
  
  public SourceNested<A> editOrNewSource() {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(new SourceBuilder().build()));
  }
  
  public SourceNested<A> editOrNewSourceLike(Source item) {
    return withNewSourceLike(java.util.Optional.ofNullable(buildSource()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuleFromFluent that = (RuleFromFluent) o;
    if (!java.util.Objects.equals(source, that.source)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(source,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  public class SourceNested<N> extends SourceFluent<SourceNested<N>> implements Nested<N>{
    SourceNested(Source item) {
      this.builder = new SourceBuilder(this, item);
    }
    SourceBuilder builder;
    
    public N and() {
      return (N) RuleFromFluent.this.withSource(builder.build());
    }
    
    public N endSource() {
      return and();
    }
    
  
  }

}
